argon2_web
The package https://pub.dev/packages/pointycastle contains argon2 in addition to many other cryptographic algorithms.
This package is for people who prefer lightweight dependencies.
It strips down the heavy pointycastle dependency to only argon2id.
Libraries
- argon2_web
- A minimal, Web-safe (dart2js/dartdevc) Argon2 implementation, decoupled from PointyCastle's registry/interface framework.