Argon2Parameters class
Configuration for Argon2BytesGenerator.
Extracted from package:pointycastle/key_derivators/api.dart - no
PointyCastle CipherParameters marker interface, just a plain class.
Constructors
Properties
- additional → Uint8List?
-
no setter
- desiredKeyLength → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterations → int
-
final
- lanes → int
-
final
- memory → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salt → Uint8List
-
no setter
- secret → Uint8List?
-
no setter
- type → int
-
final
- version → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- argon2d → const int
- argon2i → const int
- argon2id → const int
- defaultIterations → const int
- defaultLanes → const int
- defaultMemoryCost → const int
- defaultType → const int
- defaultVersion → const int
- version10 → const int
- version13 → const int